@@ -5,7 +5,7 @@ from PyObjCTools.TestSupport import *
 if sys.maxsize > 2 ** 32:
     import MapKit
 
-    class TestMKPolyline (TestCase):
+    class TestMKPolyline(TestCase):
         @min_os_level("10.9")
         def testClasses(self):
             self.assertIsInstance(MapKit.MKPolyline, objc.objc_class)
@@ -13,8 +13,11 @@ if sys.maxsize > 2 ** 32:
             self.assertArgSizeInArg(MapKit.MKPolyline.polylineWithPoints_count_, 0, 1)
             self.assertArgIsIn(MapKit.MKPolyline.polylineWithPoints_count_, 0)
 
-            self.assertArgSizeInArg(MapKit.MKPolyline.polylineWithCoordinates_count_, 0, 1)
+            self.assertArgSizeInArg(
+                MapKit.MKPolyline.polylineWithCoordinates_count_, 0, 1
+            )
             self.assertArgIsIn(MapKit.MKPolyline.polylineWithCoordinates_count_, 0)
 
+
 if __name__ == "__main__":
     main()
